@@ -14,9 +14,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-history.c 6786 2007-01-03 08:18:47Z diegoe $
+ *  $Id: ephy-history.c 7244 2007-08-06 09:16:45Z diegoe $
  */
 
 #include "config.h"
@@ -124,22 +124,6 @@ ephy_history_get_type (void)
         return type;
 }
 
-static void
-ephy_history_set_enabled (EphyHistory *history,
-			  gboolean enabled)
-{
-	LOG ("ephy_history_set_enabled %d", enabled);
-
-	history->priv->enabled = enabled;
-
-	ephy_node_db_set_immutable (history->priv->db, !enabled);
-
-	if (enabled == FALSE)
-	{
-		ephy_history_clear (history);
-	}
-}
-
 static void
 ephy_history_set_property (GObject *object,
 			   guint prop_id,
@@ -169,7 +153,7 @@ ephy_history_get_property (GObject *object,
 		case PROP_ENABLED:
 			g_value_set_boolean (value, history->priv->enabled);
 			break;
-		}
+	}
 }
 
 static void
@@ -288,7 +272,7 @@ ephy_history_save (EphyHistory *eb)
 	int ret;
 
 	/* only save if there are changes */
-	if (eb->priv->dirty == FALSE)
+	if (eb->priv->dirty == FALSE && eb->priv->enabled)
 	{
 		return;
 	}
@@ -966,11 +950,16 @@ ephy_history_set_icon (EphyHistory *gh,
 		       const char *url,
 		       const char *icon)
 {
-	EphyNode *host;
+	EphyNode *node, *host;
+	int host_id;
 
-	LOG ("Set host icon");
+	node = ephy_history_get_page (gh, url);
+	if (node == NULL) return;
+	
+	host_id = ephy_node_get_property_int (node, EPHY_NODE_PAGE_PROP_HOST_ID);
+	g_return_if_fail (host_id >= 0);
 
-	host = g_hash_table_lookup (gh->priv->hosts_hash, url);
+	host = ephy_node_db_get_node_from_id (gh->priv->db, host_id);
 	if (host)
 	{
 		ephy_node_set_property_string (host, EPHY_NODE_PAGE_PROP_ICON,
@@ -1026,3 +1015,39 @@ ephy_history_is_enabled (EphyHistory *history)
 
 	return history->priv->enabled;
 }
+
+void
+ephy_history_set_enabled (EphyHistory *history,
+			  gboolean enabled)
+{
+	int ret;
+
+	ret = 1;
+
+	LOG ("ephy_history_set_enabled %d", enabled);
+
+	/* Write history only when disabling it, not when reenabling it */
+	if (!enabled && history->priv->dirty)
+	{
+		ret = ephy_node_db_write_to_xml_safe
+			(history->priv->db, (const xmlChar *)history->priv->xml_file,
+			 EPHY_HISTORY_XML_ROOT,
+			 EPHY_HISTORY_XML_VERSION,
+			 NULL, /* comment */
+			 history->priv->hosts,
+			 (EphyNodeFilterFunc) save_filter, history->priv->pages,
+			 history->priv->pages, NULL, NULL,
+			 NULL);
+	}
+
+	if (ret >=0)
+	{
+		/* save was successful */
+		history->priv->dirty = FALSE;
+	}
+
+	history->priv->enabled = enabled;
+
+	ephy_node_db_set_immutable (history->priv->db, !enabled);
+}
+
