@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: EphyPromptService.cpp 6952 2007-03-11 19:42:02Z chpe $
+ *  $Id: EphyPromptService.cpp 7166 2007-07-15 10:19:27Z chpe $
  */
 
 #include "mozilla-config.h"
@@ -514,7 +514,7 @@ static void
 DeletePrompter (gpointer aPromptPtr,
 	        GObject *aZombie)
 {
-	Prompter *prompt = NS_STATIC_CAST (Prompter*, aPromptPtr);
+	Prompter *prompt = static_cast<Prompter*>(aPromptPtr);
 
 	delete prompt;
 }
@@ -531,7 +531,7 @@ Prompter::Show ()
 			  G_CALLBACK (gtk_widget_destroy), NULL);
 	g_object_weak_ref (G_OBJECT (mDialog),
 			   (GWeakNotify) DeletePrompter,
-			   NS_STATIC_CAST (gpointer, this));
+			   static_cast<gpointer>(this));
 
 	gtk_widget_show (GTK_WIDGET (mDialog));
 }
