@@ -13,9 +13,9 @@
  *
  *  You should have received a copy of the GNU Lesser General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: EphyUtils.cpp,v 1.23 2006/09/13 11:34:14 chpe Exp $
+ *  $Id: EphyUtils.cpp 7274 2007-08-15 07:46:04Z diegoe $
  */
 
 #include "mozilla-config.h"
@@ -128,7 +128,8 @@ EphyUtils::FindEmbed (nsIDOMWindow *aDOMWindow)
 
 	nsresult rv;
 	GtkWidget *mozembed;
-	rv = window->GetSiteWindow ((void **)&mozembed);
+	GtkWidget **cache_ptr = &mozembed;
+	rv = window->GetSiteWindow ((void **) cache_ptr);
 	NS_ENSURE_SUCCESS (rv, nsnull);
 
 	return mozembed;
