@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-file-helpers.c 7226 2007-07-30 23:52:26Z diegoe $
+ *  $Id: ephy-file-helpers.c 7300 2007-08-26 21:49:58Z diegoe $
  */
 
 #include "config.h"
@@ -46,6 +46,7 @@
 #include <libsn/sn.h>
 #include <gdk/gdk.h>
 #include <gdk/gdkx.h>
+#include <gtk/gtkrecentmanager.h>
 
 #include <string.h>
 #include <stdlib.h>
@@ -488,6 +489,17 @@ ephy_file_delete_on_exit (const char *path)
 	/* does nothing now */
 }
 
+void
+ephy_file_add_recent_item (const char *uri,
+			   const char *mime_type)
+{	
+	GtkRecentManager *manager = gtk_recent_manager_get_default ();
+
+	g_return_if_fail (mime_type != NULL && uri != NULL);
+
+	gtk_recent_manager_add_item (manager, uri);
+}
+
 static void
 load_mime_from_xml (void)
 {
