@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-password-dialog.c 6977 2007-03-28 22:22:50Z chpe $
+ *  $Id: ephy-password-dialog.c 7213 2007-07-30 05:13:42Z diegoe $
  */
 
 #ifndef DONT_HAVE_CONFIG_H
@@ -732,9 +732,3 @@ ephy_password_dialog_get_new_password (EphyPasswordDialog *dialog)
 	return gtk_entry_get_text (GTK_ENTRY (priv->entry[NEW_PASSWORD_ENTRY]));
 }
 
-void
-ephy_password_dialog_fill (EphyPasswordDialog *dialog,
-			   GList *attributes_list)
-{
-	
-}
