@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: prefs-dialog.c 6952 2007-03-11 19:42:02Z chpe $
+ *  $Id: prefs-dialog.c 7195 2007-07-25 20:34:25Z diegoe $
  */
 
 #include "config.h"
@@ -102,8 +102,7 @@ static const char * const size_prefs [] =
 	CONF_RENDERING_FONT_MIN_SIZE
 };
 
-const
-int default_size [] =
+static const int default_size [] =
 {
 	10,
 	11,
@@ -128,6 +127,7 @@ enum
 	MIN_SIZE_PROP,
 	FONT_PREFS_BUTTON_PROP,
 	USE_COLORS_PROP,
+	SMOOTHSCROLL_PROP,
 	CSS_CONTAINER_PROP,
 	CSS_CHECKBOX_PROP,
 	CSS_EDIT_BOX_PROP,
@@ -173,6 +173,7 @@ EphyDialogProperty properties [] =
 	{ "min_size_spinbutton",	CONF_RENDERING_FONT_MIN_SIZE,	PT_AUTOAPPLY,	0 },
 	{ "font_prefs_button",		NULL,				PT_NORMAL,	0 },
 	{ "use_colors_checkbutton",	CONF_RENDERING_USE_OWN_COLORS,	PT_AUTOAPPLY | PT_INVERTED,	0 },
+	{ "smoothscroll_button",	CONF_DISPLAY_SMOOTHSCROLL,	PT_AUTOAPPLY,	0 },
 	{ "css_container",		NULL,				PT_NORMAL,	0 },
 	{ "css_checkbox",		CONF_USER_CSS_ENABLED,		PT_AUTOAPPLY,	0 },
 	{ "css_edit_box",		NULL,				PT_NORMAL,	0 },
@@ -371,7 +372,7 @@ prefs_dialog_show_help (EphyDialog *dialog)
 	GtkWidget *window, *notebook;
 	int id;
 
-	static char * const help_preferences[] = {
+	static const char help_preferences[][28] = {
 		"general-preferences",
 		"fonts-and-style-preferences",
 		"privacy-preferences",
