@@ -13,9 +13,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: window-commands.c 6816 2007-01-10 00:38:52Z chpe $
+ *  $Id: window-commands.c 7522 2007-10-07 16:59:18Z diegoe $
  */
 
 #include "config.h"
@@ -738,7 +738,7 @@ window_cmd_help_about (GtkAction *action,
 		   "GNU General Public License for more details."),
 		N_("You should have received a copy of the GNU General Public License "
 		   "along with the GNOME Web Browser; if not, write to the Free Software Foundation, Inc., "
-		   "59 Temple Place, Suite 330, Boston, MA  02111-1307  USA")
+		   "51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA")
 	};
 
 	EphyEmbedShell *shell;
@@ -946,9 +946,17 @@ window_cmd_load_location (GtkAction *action,
 
 	if (location)
 	{
-		ephy_link_open (EPHY_LINK (window), location,
+		EphyBookmarks *bookmarks;
+		char *address;
+
+		bookmarks = ephy_shell_get_bookmarks (ephy_shell_get_default ());
+
+		address = ephy_bookmarks_resolve_address (bookmarks, location, NULL);
+		g_return_if_fail (address != NULL);
+
+		ephy_link_open (EPHY_LINK (window), address,
 			        ephy_window_get_active_tab (window),
-				ephy_link_flags_from_current_event ());
+				ephy_link_flags_from_current_event () | EPHY_LINK_ALLOW_FIXUP);
 	}
 }
 
